0.2.0
=====

* Introduce a changelog

* A Twisted application file is now provided (Issue #58)

* Additional configuration options have been added (Issue #57)

* Blocking calls are no longer used within Twisted (Issue #52)

* The server now re-uses TCP connections to RabbitMQ (Issue #50)

* The server now responds with HTTP 404 rather than HTTP 200 when a resource is
  not found (Issue #45)
